@@ -2,7 +2,10 @@
 
 #include "StdAfx.h"
 
-#include "../../../Common/Alloc.h"
+extern "C" 
+{ 
+#include "../../../../C/Alloc.h"
+}
 
 #include "BZip2Encoder.h"
 
@@ -23,14 +26,14 @@ const int kMaxHuffmanLenForEncoding = 16; // it must be < kMaxHuffmanLen = 20
 static const UInt32 kBufferSize = (1 << 17);
 static const int kNumHuffPasses = 4;
 
-bool CThreadInfo::Create()
+bool CThreadInfo::Alloc()
 {
-  if (m_BlockSorterIndex != 0)
-    return true;
-  m_BlockSorterIndex = (UInt32 *)::BigAlloc(BLOCK_SORT_BUF_SIZE(kBlockSizeMax) * sizeof(UInt32));
   if (m_BlockSorterIndex == 0)
-    return false;
-
+  {
+    m_BlockSorterIndex = (UInt32 *)::BigAlloc(BLOCK_SORT_BUF_SIZE(kBlockSizeMax) * sizeof(UInt32));
+    if (m_BlockSorterIndex == 0)
+      return false;
+  }
 
   if (m_Block == 0)
   {
@@ -52,6 +55,20 @@ void CThreadInfo::Free()
 }
 
 #ifdef COMPRESS_BZIP2_MT
+
+static THREAD_FUNC_DECL MFThread(void *threadCoderInfo)
+{
+  return ((CThreadInfo *)threadCoderInfo)->ThreadFunc();
+}
+
+HRes CThreadInfo::Create()
+{
+  RINOK(StreamWasFinishedEvent.Create());
+  RINOK(WaitingWasStartedEvent.Create());
+  RINOK(CanWriteEvent.Create());
+  return Thread.Create(MFThread, this);
+}
+
 void CThreadInfo::FinishStream(bool needLeave)
 {
   Encoder->StreamWasFinished = true;
@@ -66,6 +83,7 @@ DWORD CThreadInfo::ThreadFunc()
 {
   for (;;)
   {
+    Encoder->CanProcessEvent.Lock();
     Encoder->CS.Enter();
     if (Encoder->CloseThreads)
     {
@@ -107,10 +125,6 @@ DWORD CThreadInfo::ThreadFunc()
   }
 }
 
-static DWORD WINAPI MFThread(void *threadCoderInfo)
-{
-  return ((CThreadInfo *)threadCoderInfo)->ThreadFunc();
-}
 #endif
 
 CEncoder::CEncoder():
@@ -122,7 +136,6 @@ CEncoder::CEncoder():
   ThreadsInfo = 0;
   m_NumThreadsPrev = 0;
   NumThreads = 1;
-  CS.Enter();
   #endif
 }
 
@@ -132,33 +145,38 @@ CEncoder::~CEncoder()
   Free();
 }
 
-bool CEncoder::Create()
+HRes CEncoder::Create()
 {
+  RINOK(CanProcessEvent.CreateIfNotCreated());
+  RINOK(CanStartWaitingEvent.CreateIfNotCreated());
+  if (ThreadsInfo != 0 && m_NumThreadsPrev == NumThreads)
+    return S_OK;
   try 
   { 
-    if (ThreadsInfo != 0 && m_NumThreadsPrev == NumThreads)
-      return true;
     Free();
     MtMode = (NumThreads > 1);
     m_NumThreadsPrev = NumThreads;
     ThreadsInfo = new CThreadInfo[NumThreads];
     if (ThreadsInfo == 0)
-      return false;
-    for (UInt32 t = 0; t < NumThreads; t++)
+      return E_OUTOFMEMORY;
+  }
+  catch(...) { return E_OUTOFMEMORY; }
+  for (UInt32 t = 0; t < NumThreads; t++)
+  {
+    CThreadInfo &ti = ThreadsInfo[t];
+    ti.Encoder = this;
+    if (MtMode)
     {
-      CThreadInfo &ti = ThreadsInfo[t];
-      ti.Encoder = this;
-      if (MtMode)
-        if (!ti.Thread.Create(MFThread, &ti))
-        {
-          NumThreads = t;
-          Free();
-          return false; 
-        }
+      HRes res = ti.Create();
+      if (res != S_OK)
+      {
+        NumThreads = t;
+        Free();
+        return res; 
+      }
     }
   }
-  catch(...) { return false; }
-  return true;
+  return S_OK;
 }
 
 void CEncoder::Free()
@@ -166,7 +184,7 @@ void CEncoder::Free()
   if (!ThreadsInfo)
     return;
   CloseThreads = true;
-  CS.Leave();
+  CanProcessEvent.Set();
   for (UInt32 t = 0; t < NumThreads; t++)
   {
     CThreadInfo &ti = ThreadsInfo[t];
@@ -709,8 +727,7 @@ HRESULT CEncoder::CodeReal(ISequentialInStream *inStream,
 {
   #ifdef COMPRESS_BZIP2_MT
   Progress = progress;
-  if (!Create())
-    return E_FAIL;
+  RINOK(Create());
   for (UInt32 t = 0; t < NumThreads; t++)
   #endif
   {
@@ -726,7 +743,7 @@ HRESULT CEncoder::CodeReal(ISequentialInStream *inStream,
 
     ti.m_OptimizeNumTables = m_OptimizeNumTables;
 
-    if (!ti.Create())
+    if (!ti.Alloc())
       return E_OUTOFMEMORY;
   }
 
@@ -764,11 +781,11 @@ HRESULT CEncoder::CodeReal(ISequentialInStream *inStream,
   {
     ThreadsInfo[0].CanWriteEvent.Set();
     Result = S_OK;
-    CS.Leave();
+    CanProcessEvent.Set();
     UInt32 t;
     for (t = 0; t < NumThreads; t++)
       ThreadsInfo[t].StreamWasFinishedEvent.Lock();
-    CS.Enter();
+    CanProcessEvent.Reset();
     CanStartWaitingEvent.Set();
     for (t = 0; t < NumThreads; t++)
       ThreadsInfo[t].WaitingWasStartedEvent.Lock();
