@@ -10,21 +10,11 @@
 #include "Common/NewHandler.h"
 #include "Common/Exception.h"
 #include "Common/StringConvert.h"
-#ifdef _WIN32
-#include "Common/Alloc.h"
-#endif
 
 #include "../Common/ExitCode.h"
 #include "../Common/ArchiveCommandLine.h"
 #include "ConsoleClose.h"
 
-#ifdef CRC_GENERATE_TABLE
-extern "C" 
-{ 
-  #include "../../../../C/7zCrc.h" 
-}
-#endif
-
 using namespace NWindows;
 
 CStdOutStream *g_StdStream = 0;
@@ -64,9 +54,6 @@ int numArguments, const char *arguments[]
 #endif
 )
 {
-  #ifdef CRC_GENERATE_TABLE
-  CrcGenerateTable();
-  #endif
   g_StdStream = &g_StdOut;
   #ifdef _UNICODE
   if (!IsItWindowsNT())
@@ -75,6 +62,7 @@ int numArguments, const char *arguments[]
     return NExitCode::kFatalError;
   }
   #endif
+
   // setlocale(LC_COLLATE, ".OCP");
   NConsoleClose::CCtrlHandlerSetter ctrlHandlerSetter;
   int res = 0;
