@@ -5,9 +5,9 @@
 
 #include "../Common/String.h"
 
-#ifndef LOAD_LIBRARY_AS_DATAFILE
-#define LOAD_LIBRARY_AS_DATAFILE      0x0000000
-#endif
+// #ifndef LOAD_LIBRARY_AS_DATAFILE
+// #define LOAD_LIBRARY_AS_DATAFILE      0x0000000
+// #endif
 
 typedef void * HMODULE; // FIXME
 
@@ -42,10 +42,10 @@ public:
   // operator HMODULE() const { return _module; };
   // bool IsLoaded() const { return (_module != NULL); };
   bool Free();
-  bool LoadEx(LPCTSTR fileName, DWORD flags = LOAD_LIBRARY_AS_DATAFILE);
+  // bool LoadEx(LPCTSTR fileName, DWORD flags = LOAD_LIBRARY_AS_DATAFILE);
   bool Load(LPCTSTR fileName);
   #ifndef _UNICODE
-  bool LoadEx(LPCWSTR fileName, DWORD flags = LOAD_LIBRARY_AS_DATAFILE);
+  // bool LoadEx(LPCWSTR fileName, DWORD flags = LOAD_LIBRARY_AS_DATAFILE);
   bool Load(LPCWSTR fileName);
   #endif
   FARPROC GetProcAddress(LPCSTR procName) const;
